@@ -52,6 +52,9 @@ import pluralize
 import pydal
 import threadsafevariable
 import yatl
+import renoir
+import renoir.constants
+import renoir.writers
 
 bottle.BaseRequest.MEMFILE_MAX = 16 * 1024 * 1024
 
@@ -99,7 +102,6 @@ Is still experimental...
 """
 
 Field = pydal.Field
-render = yatl.render
 request = bottle.request
 response = bottle.response
 abort = bottle.abort
@@ -129,7 +131,7 @@ def required_folder(*parts):
     return path
 
 
-def safely(func, exceptions=(Exception,), log=False):
+def safely(func, exceptions=(Exception,), log=False, default=None):
     """
     runs the funnction and returns True on success,
     False if one of the exceptions is raised
@@ -139,7 +141,7 @@ def safely(func, exceptions=(Exception,), log=False):
     except exceptions as err:
         if log:
             logging.warn(str(err))
-        return None
+        return default() if callable(default) else default
 
 
 ########################################################################################
@@ -341,7 +343,15 @@ class DAL(pydal.DAL, Fixture):
 # make sure some variables in pydal are thread safe
 def thread_safe_pydal_patch():
     Field = pydal.DAL.Field
-    tsafe_attrs = ["readable", "writable", "default", "update", "requires", "widget"]
+    tsafe_attrs = [
+        "readable",
+        "writable",
+        "default",
+        "update",
+        "requires",
+        "widget",
+        "represent",
+    ]
     for a in tsafe_attrs:
         setattr(Field, a, threadsafevariable.ThreadSafeVariable())
 
@@ -488,6 +498,51 @@ class Flash(Fixture):
 #########################################################################################
 
 
+class RenoirXMLEscapeMixin:
+    def _escape_data(self, data):
+        """Allows Renoir to convert yatl helpers to strings"""
+        return safely(
+            lambda: data.xml(), default=lambda: self._to_html(self._to_unicode(data))
+        )
+
+
+class RenoirCustomWriter(RenoirXMLEscapeMixin, renoir.writers.Writer):
+    ...
+
+
+class RenoirCustomEscapeAllWriter(RenoirXMLEscapeMixin, renoir.writers.EscapeAllWriter):
+    ...
+
+
+class Renoir(renoir.Renoir):
+    """Custom Renoir Engine that understands yatl helpers"""
+    _writers = {
+        renoir.constants.ESCAPES.common: RenoirCustomWriter,
+        renoir.constants.ESCAPES.all: RenoirCustomEscapeAllWriter,
+    }
+
+
+def render(
+    content=None,
+    filename=None,
+    path=".",
+    context={},
+    delimiters="[[ ]]",
+    cached_renoir_engines=Cache(100),
+):
+    """
+    renders the template using renoire, same API as yatl.render, does caching of
+    both Renoire engine and source files
+    """
+    engine = cached_renoir_engines.get(
+        (path, delimiters),
+        lambda: Renoir(path=path, delimiters=delimiters.split(" "), reload=True),
+    )
+    if content is not None:
+        return engine._render(content, context=context)
+    return engine.render(filename, context=context)
+
+
 class Template(Fixture):
 
     cache = Cache(100)
@@ -497,18 +552,6 @@ class Template(Fixture):
         self.path = path
         self.delimiters = delimiters
 
-    @staticmethod
-    def reader(filename):
-        """Cached file reader, only reads template if it has changed"""
-
-        def raw_read():
-            with open(filename, encoding="utf8") as stream:
-                return stream.read()
-
-        return Template.cache.get(
-            filename, raw_read, expiration=1, monitor=lambda: os.path.getmtime(filename)
-        )
-
     def transform(self, output, shared_data=None):
         if not isinstance(output, dict):
             return output
@@ -526,12 +569,8 @@ class Template(Fixture):
             generic_filename = os.path.join(path, "generic.html")
             if os.path.exists(generic_filename):
                 filename = generic_filename
-        output = yatl.render(
-            Template.reader(filename),
-            path=path,
-            context=context,
-            delimiters=self.delimiters,
-            reader=Template.reader,
+        output = render(
+            filename=filename, path=path, context=context, delimiters=self.delimiters
         )
         return output
 
@@ -1109,7 +1148,7 @@ class ErrorLogger:
         def log(app_name, error_snap_shop):
             ...
             return ticket_uuid
-    
+
     error_logger.plugins['app_name'] = MyLogger()
     """
 
@@ -1282,6 +1321,7 @@ ERROR_PAGES = {
     "*": '<html><head><style>body{color:white;text-align: center;background-color:[[=color]];font-family:serif} h1{font-size:6em;margin:16vh 0 8vh 0} h2{font-size:2em;margin:8vh 0} a{color:white;text-decoration:none;font-weight:bold;padding:10px 10px;border-radius:10px;border:2px solid #fff;transition: all .5s ease} a:hover{background:rgba(0,0,0,0.1);padding:10px 30px}</style></head><body><h1>[[=code]]</h1><h2>[[=message]]</h2>[[if button_text:]]<a href="[[=href]]">[[=button_text]]</a>[[pass]]</body></html>',
 }
 
+
 def error_page(code, button_text=None, href="#", color=None, message=None):
     message = http.client.responses[code].upper() if message is None else message
     color = (
@@ -1298,7 +1338,7 @@ def error_page(code, button_text=None, href="#", color=None, message=None):
         return json.dumps(context)
     # else - return html error-page
     content = ERROR_PAGES.get(code) or ERROR_PAGES["*"]
-    return yatl.render(content, context=context, delimiters="[[ ]]")
+    return render(content=content, context=context, delimiters="[[ ]]")
 
 
 @bottle.error(404)
@@ -1811,7 +1851,7 @@ def new_app(apps_folder, app_name, yes, scaffold_zip):
 )
 @click.option(
     "--watch",
-    default="off",
+    default="lazy",
     type=click.Choice(["off", "sync", "lazy"]),
     help="Watch python changes and reload apps automatically, modes: off, sync, lazy",
     show_default=True,
