@@ -289,7 +289,7 @@ class FormStyleFactory:
         kwargs = kwargs if kwargs else {}
 
         form_method = "POST"
-        form_action = request.url
+        form_action = request.url.split(":", 1)[1]
         form_enctype = "multipart/form-data"
 
         form = FORM(
