@@ -533,7 +533,7 @@ class Grid:
 
             readonly = self.action == "details"
 
-            attrs = self.attributes_plugin.form(url=request.url)
+            attrs = self.attributes_plugin.form(url=request.url.split(":", 1)[1])
             self.form = Form(
                 table,
                 record=record,
@@ -647,7 +647,13 @@ class Grid:
             if self.total_number_of_rows % self.param.rows_per_page > 0:
                 self.number_of_pages += 1
 
-        if self.param.details or self.param.editable or self.param.deletable:
+        if (
+            self.param.pre_action_buttons
+            or self.param.details
+            or self.param.editable
+            or self.param.deletable
+            or self.param.post_action_buttons
+        ):
             self.param.columns.append(
                 Column("", self.make_action_buttons, td_class_style="grid-td-buttons")
             )
@@ -694,6 +700,7 @@ class Grid:
         row_id=None,
         name="grid-button",
         row=None,
+        ignore_attribute_plugin=False,
         **attrs,
     ):
         separator = "?"
@@ -730,7 +737,11 @@ class Grid:
         if callable(url):
             url = url(row)
 
-        attrs.update(self.attributes_plugin.link(url=url))
+        if ignore_attribute_plugin:
+            attrs.update({"_href": url})
+        else:
+            attrs.update(self.attributes_plugin.link(url=url))
+
         link = A(
             I(_class="fa %s" % icon),
             _role="button",
@@ -759,7 +770,7 @@ class Grid:
             for key in request.query
             if not key in ("search_type", "search_string")
         ]
-        attrs = self.attributes_plugin.form(url=self.endpoint)
+        attrs = self.attributes_plugin.link(url=self.endpoint)
         form = FORM(*hidden_fields, **attrs)
         select = SELECT(
             *options,
@@ -1011,9 +1022,16 @@ class Grid:
     def make_action_buttons(self, row):
         cat = CAT()
         row_id = row[self.param.field_id] if self.param.field_id else row.id
-
         if self.param.pre_action_buttons and len(self.param.pre_action_buttons) > 0:
             for btn in self.param.pre_action_buttons:
+                if callable(btn):
+                    # a button can be a callable, to indicate whether or not a button should
+                    # be displayed. call the function with the row object
+                    btn = btn(row)
+                    if btn == None:
+                        # if None was returned, no button is available for this row: ignore this value in the
+                        # list
+                        continue
                 cat.append(
                     self._make_action_button(
                         url=btn.url,
@@ -1022,6 +1040,10 @@ class Grid:
                         additional_classes=btn.additional_classes,
                         message=btn.message,
                         row_id=row_id if btn.append_id else None,
+                        row=row,
+                        ignore_attribute_plugin=btn.ignore_attribute_plugin
+                        if "ignore_attribute_plugin" in btn.__dict__
+                        else False,
                     )
                 )
 
@@ -1078,6 +1100,14 @@ class Grid:
 
         if self.param.post_action_buttons and len(self.param.post_action_buttons) > 0:
             for btn in self.param.post_action_buttons:
+                if callable(btn):
+                    # a button can be a callable, to indicate whether or not a button should
+                    # be displayed. call the function with the row object
+                    btn = btn(row)
+                    if btn == None:
+                        # if None was returned, no button is available for this row: ignore this value in the
+                        # list
+                        continue
                 cat.append(
                     self._make_action_button(
                         url=btn.url,
@@ -1086,6 +1116,10 @@ class Grid:
                         additional_classes=btn.additional_classes,
                         message=btn.message,
                         row_id=row_id if btn.append_id else None,
+                        row=row,
+                        ignore_attribute_plugin=btn.ignore_attribute_plugin
+                        if "ignore_attribute_plugin" in btn.__dict__
+                        else False,
                     )
                 )
 
@@ -1336,6 +1370,7 @@ class AttributesPluginHtmx(AttributesPlugin):
     def form(self, url):
         attrs = copy.copy(self.default_attrs)
         attrs["_hx-post"] = url
+        attrs["_hx-encoding"] = "multipart/form-data"
         return attrs
 
     def link(self, url):
