@@ -57,7 +57,7 @@ LOGGERS = [
 ]  # syntax "severity:filename" filename can be stderr or stdout
 
 # Disable default login when using OAuth
-DEFAULT_LOGIN_ENABLED = False
+DEFAULT_LOGIN_ENABLED = True
 
 # single sign on Google (will be used if provided)
 OAUTH2GOOGLE_CLIENT_ID = None
